/* Bluefish HTML Editor
 * snr.h - search 'n replace prototypes
 *
 * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
 *
 * A part of the code in this file was taken from gEdit !
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __SNR_H_
#define __SNR_H_

#include <glib.h>
#include <gtk/gtkwidget.h>

void copy_cb(GtkWidget * w, gpointer data);
void paste_cb(GtkWidget * w, gpointer data);
void cut_cb(GtkWidget * w, gpointer data);
void sel_all_cb(GtkWidget * w, gpointer data);

void search_search_cmd_cb(GtkWidget * w, gpointer data);
void search_replace_cmd_cb(GtkWidget * w, gpointer data);
void search_again_cmd_cb(GtkWidget * w, gpointer data);
void snr_init();

#endif							/* __SNR_H_ */
